@@ -50,11 +50,11 @@ impl Content {
         &self.date_posted
     }
 
-    pub fn is_valid() -> bool {
+    pub fn is_valid(&self) -> bool {
         true
     }
 
-    pub fn compute_priority() -> i32 {
+    pub fn compute_priority(&self) -> i32 {
         100
     }
 }
